{TSamp3 - This TISAPI example creates a page with a form on it.  When the form
          is submitted, a new page is generated, which tells us what we selected}

library Tsamp3;

uses
  SysUtils, Classes, Windows,
  ISAPI, TISAPILt;

// GetExtensionVersion is required by the MS IIS.  Don't mess with it.
// CASE MATTERS FOR THIS FUNCTION NAME
function GetExtensionVersion(var ver: THSE_VERSION_INFO): Boolean; stdcall;
begin
  ver.dwExtensionVersion := MAKELONG(HSE_VERSION_MINOR, HSE_VERSION_MAJOR);
  StrPCopy(ver.lpszExtensionDesc, 'Delphi ISAPI DLL');
  result:=True;
end;

// CASE MATTERS FOR THIS FUNCTION NAME
function HttpExtensionProc(var ecb: TEXTENSION_CONTROL_BLOCK): LongInt; stdcall;
var
  MyISAPI : TISAPI;
  VarList : TStringList;
  i : Integer;

begin
  MyISAPI := TISAPI.Create; //Create our TECB and assign its published data elements
  with MyISAPI do
  begin
    try
      SetECB(@ecb);    //Set the ECB pointer - Note the @ operator

      {For this example, we'll check the form variables.  If there aren't any, we'll
      create a form on the fly.  If there are variables, we'll print out their values}

      if VarCount = 0 then  // If true, this must be the first time the DLL is called
      begin
        SendStdHeader;    //Necessary for most TISAPI commands to work
        // Here's our web page
        SendLn('<HTML><HEAD><TITLE>TISAPI 2.0 Form Test</TITLE></HEAD>');
        SendLn('<BODY>');
        SendLn('<H1>TISAPI 2.0 Form Test</H1>');
        SendLn('This form uses the POST method<P>');
        SendLn('<FORM action="/scripts/TSamp3.dll" method=post>');

        // Here's a TextArea Control
        SendLn('Text Area<BR>');
        SendLn('<Textarea Name="TA" Value="Enter Something Here" Rows="3" Cols="40">');
        SendLn('</Textarea><P>');

        // Here's a check box control
        SendLn('Check Me: <INPUT TYPE="CHECKBOX" NAME="check1" VALUE="Checked">');
        SendLn('<P>');

        // Here's a text input field
        SendLn('Enter text: <Input Type="Text" Name="Tx" Size="40" Maxlength="40">');
        SendLn('</Input><P>');

        // Here's a List Box
        SendLn('Favorite Color(s) (You can select more than one)<BR>');
        SendLn('<SELECT NAME="Color" SIZE=3 MULTIPLE>');
        SendLn('<OPTION>Red');
        SendLn('<OPTION>Orange');
        SendLn('<OPTION>Yellow');
        SendLn('<OPTION>Green');
        SendLn('<OPTION>Blue');
        SendLn('<OPTION>Indigo');
        SendLn('<OPTION>Violet');
        SendLn('</SELECT><P>');

        // Here's our submit button
        SendLn('<INPUT type="submit" value="Submit the Form"></FORM><P>');

        // Finish up the page
        SendLn('<HR>');
        SendLn('Thank you for trying our form');
        SendLn('</BODY></HTML>');
      end
      else  // The following is called if there are form variables in the request
      begin
//        Spillit;

        SendStdHeader;    //Necessary for most TISAPI commands to work
        // Here's our web page
        SendLn('<HTML><HEAD><TITLE>TISAPI Form Results</TITLE></HEAD>');
        SendLn('<BODY>');
        SendLn('<H1>TISAPI Form Results</H1>');

        // Check the Text Area
        if GetPageVar('TA') <> '' then
          SendLn('You typed "' +  GetPageVar('TA') + '" in the text area<P>')
        else
          SendLn('You left the text area blank' + '<P>');

        // look at the check box
        if IsPageVar('check1') then  //The page var won't exist if it wasn't checked
          SendLn('You Checked the Box' + '<P>')
        else
          SendLn('You Didn''t Check the Box' + '<P>');

        // look at the text area
        if GetPageVar('Tx') <> '' then
          SendLn('You typed "' +  GetPageVar('Tx') + '" in the text input field<P>')
        else
          SendLn('You left the Text Input Field blank' + '<P>');

        // look at the list box - Demonstrates the GetPageVarList method
        // There's no need to use TStringList.Create. GetPageVarList does it for you
        VarList := GetPageVarList('Color');
        if VarList <> nil then
        begin
          SendLn('You picked ' + IntToStr(VarList.Count) + ' Colors');
          SendLn('Your favorite color(s):<BR>');
          for i := 0 to VarList.Count-1 do
            SendLn(VarList[i] + '<BR>');
          SendLn('<BR>');
          VarList.Free;
        end
        else
          SendLn('You left the Color Field blank' + '<P>');

        // Here's some other information
        SendLn('Here''s some other info (just for fun)<P>');
        SendLn('Your browser is: ' + GetServerVar('HTTP_USER_AGENT'));
        SendLn('<BR>');
        SendLn('Your IP address is: ' + GetServerVar('REMOTE_ADDR'));
        SendLn('<P>');

        // Let's try it again
        SendLn('<A HREF="/scripts/Tsamp3.dll">Click here to try it again</A>');
        SendLn('<P>');

        // Finish up the page
        SendLn('<HR>');
        SendLn('Thank you for trying our form');
        SendLn('</BODY></HTML>');
      end;
    finally
      Free;             // DON'T FORGET TO RELEASE THE RESOURCES
    end;
  end;

  result := HSE_STATUS_SUCCESS;  // That's all folks
end;

// * REQUIRED FOR DYNAMIC BINDING.
// * Index values aren't needed.
// * Case doesn't matter here.
exports
  GetExtensionVersion,
  HttpExtensionProc;

begin
end.
